# def wprint(variables, sep ='\n'):
#     vars = variables.split(',')
#     for var in vars:
#       print(var.strip(), '=', repr(eval(var)), end = sep)

import inspect
import re

def wprint(*args):
    frame = inspect.currentframe().f_back
    s = inspect.getframeinfo(frame).code_context[0]
    r = re.search(r"\((.*)\)", s).group(1)
    vnames = r.split(", ")
    for i,(var,val) in enumerate(zip(vnames, args)):
        print(f"{var} = {val}")